

(****************************************************************)
(* Application example with AVRco LCD Graphics Library using    *)
(* the 7" TFT display.                                          *)
(* This display has a 8bit interface and SPI Touch              *)
(*                                                              *)
(* Controller = SSD1963                                         *)
(* The resolution of the display is 800x480 pixels.             *)
(*                                                              *)
(* 8bit data port on PortA D0..D7                               *)
(* D8..D15 connected to GND                                     *)
(*                                                              *)
(* Option: enable 16 bit mode {$DEFINE LCD16BIT}                *)
(* In 16 bit mode data port on PortA D0..D7                     *)
(* D8..D15 connected to PortF                                   *)
(*                                                              *)
(* LCD control Pins on PortB                                    *)
(* LCD_RS    PortB.0                                            *)
(* LCD_WR    PortB.1                                            *)
(* LCD_RD    PortB.2;                                           *)
(* LCD_CS    PortB.3;                                           *)
(* LCD_RST   PortB.4;                                           *)
(* Touch Controller IRQ pin on PortB.7                          *)
(*                                                              *)
(* Touch Controller is connected to SPI_D                       *)
(* PortD.7 = SCLK			                        *)
(* PortD.6 = MISO <- SDO                                        *)
(* PortD.5 = MOSI -> SDI                                        *)
(* PortD.4 = CS                                                 *)
(****************************************************************)

program TFT_LCD;

{$NOSHADOW}
{ $WG}                     {global Warnings off}


{$DEFINE LCD16BIT}

Device = xmega256A3U, VCC=3.3;
{ $BOOTRST $20000}         {Reset Jump to $20000}

Define_Fuses
//  Override_Fuses;
  NoteBook   = A;
  COMport    = USB;
  LockBits0  = [];
  FuseBits0  = [];
  FuseBits1  = [];
  FuseBits2  = [];
  ProgMode   = PDI;


import SysTick,
       //  SPI_D,
    LCDGraphic,
     SerPortC1,
     SerPortE1;


from LCDGraphic import CharSet;     {block CharSet, pixels}
from LCDGraphic import GraphColor;  {simple color support, read only mode}
from System import Processes, fix64, Random;

Define
// The XMegas don't provide any Oscillator fuses.
// So the application must setup the desired values 
// possible OSC types: extXTAL, extClock, ext32kHz, int32Khz, int2MHz, int32MHz
  OSCtype        = int2MHz,
                   PLLmul  = 28,
                   prescB  = 1,
                   prescB  = 1, overdrive;
  SysTick        = 10;             {msec}
  StackSize      = $0100, iData;
  FrameSize      = $0120, iData;
  
  
  
  LCDGraphic     = 800, 480, 8;         // x-pix, y-pix, accesswidth
  LCDgraphMode   = XYaddress, iData;    // linear mode
  DefCharSet     = 'Graphchars.pchr';   // FileName
  GViewports     = 6, iData;            // logical ViewPorts, scalings
  TGraphStr      = 32;                  // Graphic Text String Length




//Serielle neu C1 kommt von Base
  SerPortC1        = 115200, Stop1;                // Zum TFT
  RxBufferC1       = 64, iData;
  TxBufferC1       = 64, iData;


//Kommt von IRQ uC am mein TFT alt D0  neu E1
  SerPortE1      = 250000, Stop1; //115200, Stop1;
  RxBufferE1     = $FF,  iData;
  TxBufferE1     = $10,  iData;

  
  Scheduler      = iData; //iData;


Implementation

{$IDATA}

{--------------------------------------------------------------}
{ Type Declarations }

type
  // enum for color lookup table
  tColors        = (clNone, clAqua, clBlack, clBlue, clCream, clDkGray, clFuchsia,
                    clGray, clGreen, clLime, clLtGray, clMaroon, clMedGray,
                    clMoneyGreen, clNavy, clOlive, clPurple, clRed, clSilver,
                    clSkyBlue, clTeal, clWhite, clYellow, clMagenta, clCyan);

{$IFDEF LCD16BIT}
  tColorArr      = array[tColors] of word;
{$ELSE}
  tColorArr      = array[tColors] of longword;
{$ENDIF}


 // 0= ribbon cable on down 1= ribbon cable on right, 3= ribbon cable on left
  TOrientation   = (SWITCH_NONE, FLIP_X, FLIP_Y, FLIP_XY);


{--------------------------------------------------------------}
{ Const Declarations }
{--------------------------------------------------------------}
const
  _TFTWIDTH      : word = 800;
  _TFTHEIGHT     : word = 480;

const
  DELAY                                : byte = $80;
  SSD1963_ADDR_MODE_FLIP_VERT          : byte = (1 shl 0);
  SSD1963_ADDR_MODE_FLIP_HORZ          : byte = (1 shl 1);
  SSD1963_ADDR_MODE_LATCH_RIGHT_TO_LEFT : byte = (1 shl 2);
  SSD1963_ADDR_MODE_BGR                : byte = (1 shl 3);
  SSD1963_ADDR_MODE_REFRESH_BOTTOM_UP  : byte = (1 shl 4);
  SSD1963_ADDR_MODE_PAG_COL_ADDR_ORDER : byte = (1 shl 5);
  SSD1963_ADDR_MODE_COL_ADDR_ORDER     : byte = (1 shl 6);
  SSD1963_ADDR_MODE_PAGE_ADDR_ORDER    : byte = (1 shl 7);


const
{$IFDEF LCD16BIT}
  // color lookup table  RGB656
  ColorArr : tColorArr = ($8888,       // clNone,
                          $07FF,       // clAqua,
                          $0000,       // clBlack,
                          $001F,       // clBlue
                          $E718,       // clCream
                          $7BEF,       // clDkGray
                          $E018,       // clFuchsia

                          $9472,       // clGray
                          $07E0,       // clGreen
                          $1FE0,       // clLime
                          $C618,       // clLtGray
                          $8000,       // clMaroon
                          $73AE,       // clMedGray
                          $7D0C,       // clMoneyGreen

                          $0010,       // clNavy
                          $BCEA,       // clOlive
                          $F81F,       // clPurple
                          $F800,       // clRed
                          $C61C,       // clSilver
                          $9E1C,       // clSkyBlue
                          $0410,       // clTeal

                          $FFFF,       // clWhite
                          $FFE0,       // clYellow
                          $F81F,       // clMAGENTA
                          $07FF);      // clCyan



{$ELSE}
   // color lookup table  // RGB666  $00RRGGBB
  ColorArr : tColorArr = ($00008888,       // clNone,
                          $0000FFFF,       // clAqua,
                          $00000000,       // clBlack,
                          $000000FF,       // clBlue
                          $00FFFDD0,       // clCream
                          $00A9A9A9,       // clDkGray
                          $00FF00FF,       // clFuchsia

                          $00808080,       // clGray
                          $0000FF00,       // clGreen
                          $0000FF00,       // clLime
                          $00D3D3D3,       // clLtGray
                          $00800000,       // clMaroon
                          $00A4A0A0,       // clMedGray
                          $00C0DCC0,       // clMoneyGreen

                          $00000080,       // clNavy
                          $00808000,       // clOlive
                          $00800080,       // clPurple
                          $00FF0000,       // clRed
                          $00C0C0C0,       // clSilver
                          $0087CEEB,       // clSkyBlue
                          $00008080,       // clTeal

                          $00FFFFFF,       // clWhite
                          $00FFFF00,       // clYellow
                          $00FF00FF,       // clMAGENTA
                          $0000FFFF);      // clCyan
{$ENDIF}
const
  myBkGround     : tColors = clBlack;             // clWhite;
  myForGround    : tColors = clWhite;             // clBlack;
  myLineColor    : tColors = clRed;               // clBlue
  myTextColor    : tColors = clYellow;            // clBlue
  myBtnColor     : tColors = clGray;

  LCD_RSpin      : byte    = 0;
  LCD_WRpin      : byte    = 1;
  LCD_RDpin      : byte    = 2;
  LCD_CSpin      : byte    = 3;
  LCD_RSTpin     : byte    = 4;

  LCD_IRQpin     : byte    = 7; // touch

  LCD_RSmask     : byte    = 1 shl LCD_RSpin;
  LCD_WRmask     : byte    = 1 shl LCD_WRpin;
  LCD_RDmask     : byte    = 1 shl LCD_RDpin;
  LCD_CSmask     : byte    = 1 shl LCD_CSpin;
  LCD_RSTmask    : byte    = 1 shl LCD_RSTpin;
  LCD_IRQmask    : byte    = 1 shl LCD_IRQpin;
  
  
  
  
{--------------------------------------------------------------}
{ Var Declarations }
{$IDATA}
var

  LCD_DDRCTRL[@DDRB]                : byte;   // Port B = control Pins
  LCD_PORTCTRL[@PortB]              : byte;   //
{$IFDEF LCD16BIT}
  LCD_DDRDATAH[@DDRF]               : byte;   // D8 - D15  Port F
  LCD_DATAH[@PortF]                 : byte;   //
{$ENDIF}
  LCD_DDRDATA[@DDRA]                : byte;   // D0 - D7   Port A
  LCD_DATA[@PortA]                  : byte;

  LCD_RS[@LCD_PORTCTRL, LCD_RSpin]  : bit;
  LCD_WR[@LCD_PORTCTRL, LCD_WRpin]  : bit;
  LCD_RD[@LCD_PORTCTRL, LCD_RDpin]  : bit;
  LCD_CS[@LCD_PORTCTRL, LCD_CSpin]  : bit;
  LCD_RST[@LCD_PORTCTRL, LCD_RSTpin] : bit;
  
var
  _width                            : word;
  _height                           : word;
  ptr                               : pointer;
  ch                                : char;
  pwm, bb                           : byte;
  idx, idy, x, y, i,
  angle                             : integer;
{$IFDEF LCD16BIT}
  ColorWfg, ColorWbg                : word;
{$ELSE}
  ColorWfg, ColorWbg                : longword;
{$ENDIF}
  ColorPfG, ColorPbg                : byte;
  pxCount, ww                       : word;
  
//=====================  Meine Var =============================================

  
  

{--------------------------------------------------------------}
{ functions }

{$NOFRAME}

procedure WriteRegister(data : byte);
begin
  LCD_RS:= false;
  LCD_DATA:= data;
  LCD_WR:= false;
  LCD_WR:= true;
  LCD_RS:= true;
end;

{$NOFRAME}

procedure WriteData(data : byte);
begin
  LCD_DATA:= data;
  LCD_WR:= false;
  LCD_WR:= true;
end;

{$NOFRAME}


procedure WriteWord(data : word);
begin
  LCD_DATA:= Hi(data);
  LCD_WR:= false;
  LCD_WR:= true;
  LCD_DATA:= Lo(data);
  LCD_WR:= false;
  LCD_WR:= true;
end;

{$NOFRAME}

procedure WriteColor(data : {$IFDEF LCD16BIT} word{$ELSE} longword{$ENDIF});
var
  wl[@data]     : byte;
  wh[@data + 1] : byte;
  whl[@data + 2] : byte;
begin
{$IFDEF LCD16BIT}
  asm;
    STS       %.LCD_DATA, _ACCB
    STS       %.LCD_DATAH, _ACCA
  endasm;
  LCD_WR:= false;
  LCD_WR:= true;
{$ELSE}
  LCD_DATA:= whl;     // red
  LCD_WR:= false;
  LCD_WR:= true;
  LCD_DATA:= wh;      // green
  LCD_WR:= false;
  LCD_WR:= true;
  LCD_DATA:= wl;      // blue
  LCD_WR:= false;
  LCD_WR:= true;
{$ENDIF}
end;

// XY-addressing mode
procedure SetWindow(x0, y0, x1, y1 : word);
begin
  WriteRegister($2A);
  WriteWord(x0);
  WriteWord(x1);
  WriteRegister($2B);
  WriteWord(y0);
  WriteWord(y1);
  WriteRegister($2C);
end;

// 0= ribbon cable on down 1= ribbon cable on right, 3= ribbon cable on left
procedure SetRotation(m : TOrientation); // 0..3,
begin
  LCD_CS:= false;
  WriteRegister($36);
  case m of
    SWITCH_NONE :
                  WriteData($01); // ??????
                  _width:= _TFTWIDTH;
                  _height:= _TFTHEIGHT;
                |
    FLIP_X      :
                  WriteData(SSD1963_ADDR_MODE_PAGE_ADDR_ORDER or
                            SSD1963_ADDR_MODE_PAG_COL_ADDR_ORDER);
                  _width:= _TFTHEIGHT;
                  _height:= _TFTWIDTH;
                |
    FLIP_Y      :
                  WriteData(SSD1963_ADDR_MODE_PAGE_ADDR_ORDER or
                            SSD1963_ADDR_MODE_COL_ADDR_ORDER or
                            SSD1963_ADDR_MODE_PAG_COL_ADDR_ORDER);
                  _width:= _TFTWIDTH;
                  _height:= _TFTHEIGHT;
                |
    FLIP_XY     :
                  WriteData(SSD1963_ADDR_MODE_PAGE_ADDR_ORDER or
                            SSD1963_ADDR_MODE_COL_ADDR_ORDER);
                  _width:= _TFTHEIGHT;
                  _height:= _TFTWIDTH;
                |
  endcase;
  LCD_CS:= true;
end;

procedure lcdReset;
begin
  LCD_CS:= true;
  LCD_RS:= true;
  LCD_WR:= true;
  LCD_RD:= true;
  LCD_RST:= true;
  mdelay(2);
  LCD_RST:= false;
  mdelay(10);
  LCD_RST:= true;
  mdelay(10);
end;

procedure SetBackLight(intensity : byte);
begin
  LCD_CS:= false;
  WriteRegister($BE);
  // PWMF[7:0] = 2, PWM base freq = PLL/(256*(PMWF))/256 =
  // 300Hz for a PLL freq = 120MHz
  WriteData($03);
  // Set duty cycle, from 0x00 (total pull-down) to 0xFF
  // (99% pull-up , 255/256)
  WriteData(intensity);
  // PWM enabled and controlled by host (mcu)
  WriteData($01);
  WriteData($00);
  WriteData($00);
  WriteData($00);
  LCD_CS:= true;
end;

procedure Init_Lcd;
begin
  lcdReset;
  LCD_CS:= false;
  WriteRegister($01);    // software reset
  WriteRegister($01);
  WriteRegister($01);
  mdelay(10);
  WriteRegister($E0);   // PLL enable
  WriteData($01);
  udelay(10);
  WriteRegister($E0);
  WriteData($03);
  udelay(10);

  WriteRegister($B0);   // LCD SPECIFICATION
  WriteData($08);
  WriteData($80);
  WriteData($03);       // Set HDP	799
  WriteData($1F);
  WriteData($01);       // Set VDP	479
  WriteData($DF);
  WriteData($00);

{$IFDEF LCD16BIT}
  WriteRegister($F0);    // pixel data interface
  WriteData($03);
  mdelay(1);
  WriteRegister($3A);
  WriteData($50);        // SET R G B format = 5 6 5
{$ELSE}
  WriteRegister($F0);
  WriteData($00);        // SET pixel data I/F format = 8bit
  mdelay(1);
  WriteRegister($3A);
  WriteData($60);        // SET R G B format = 6 6 6
{$ENDIF}
  mdelay(1);

  WriteRegister($E2);
  WriteData($22);
  WriteData($03);
  WriteData($04);

  WriteRegister($E6);   // PLL setting for PCLK, depends on resolution
  WriteData($00);
  WriteData($E7);
  WriteData($4F);

  WriteRegister($B4);   // HSYNC
  WriteData($20);       // Set HT	928
  WriteData($AF);
  WriteData($00);       // Set HPS	46
  WriteData($A3);
  WriteData($07);       // Set HPW	48
  WriteData($00);       // Set LPS	15
  WriteData($00);
  WriteData($00);

  WriteRegister($B6);   // VSYNC
  WriteData($01);       // Set VT	525
  WriteData($EF);
  WriteData($00);       // Set VPS	16
  WriteData($04);
  WriteData($01);       // Set VPW	16
  WriteData($00);       // Set FPS	8
  WriteData($00);

  WriteRegister($2A);    // SET column address
  WriteData($00);        // SET start column address=0
  WriteData($00);
  WriteData(Hi(_TFTWIDTH - 1));     // SET end column address=800
  WriteData(Lo(_TFTWIDTH - 1));

  WriteRegister($2B);               // SET page address
  WriteData($00);                   // SET start page address=0
  WriteData($00);
  WriteData(Hi(_TFTHEIGHT - 1));    // SET end page address=480
  WriteData(Lo(_TFTHEIGHT - 1));

  WriteRegister($29);               // display on
  WriteRegister($2C);
  LCD_CS:= true;
  SetBackLight(0);
  WriteRegister($D0);               // controls de backlight
  WriteData($0D);
end;

// speed results with 8 bit interface 580 ms and with 16 bit IF 100 ms for FillScreen :)
procedure FillRect(xs, ys, xe, ye : word; color : {$IFDEF LCD16BIT} word{$ELSE} longword{$ENDIF});
begin
  LCD_CS:= false;
  SetWindow(xs, ys, xe, ye);
  xe:= (xe - xs) + 1;
  ye:= (ye - ys) + 1;
{$IFDEF LCD16BIT}
  asm;
    ;LDI       _ACCAHI, %.LCD_WRmask
    LDD       _ACCA, Y+01        // color hi
    LDD       _ACCB, Y+00        // color lo
    STS       %.LCD_DATA, _ACCB
    STS       %.LCD_DATAH, _ACCA

    LDD       _ACCCHI, Y+3       // ye
    LDD       _ACCCLO, Y+2
    _LOOPFILL:
    LDD       _ACCBHI, Y+5       // xe
    LDD       _ACCBLO, Y+4
    _LOOPPUSH:
    ;STS       OUTCLRB, _ACCAHI
    ;STS       OUTSETB, _ACCAHI
  endasm;
  LCD_WR:= false;
  LCD_WR:= true;
  asm;
    SBIW      _ACCBLO, 1
    BRNE      _LOOPPUSH
    SBIW      _ACCCLO, 1
    BRNE      _LOOPFILL
  endasm;
{$ELSE}
  asm;
    LDD       _ACCALO, Y+02      // blue
    LDD       _ACCCHI, Y+5       // ye
    LDD       _ACCCLO, Y+4
    _LOOPFILL:
    LDD       _ACCBHI, Y+7       // xe
    LDD       _ACCBLO, Y+6
    _LOOPPUSH:
    LDD       _ACCB, Y+00        // red
    LDD       _ACCA, Y+01        // green
    // LDD       _ACCALO, Y+02   // blue
    RCALL      %.WriteColor
    SBIW      _ACCBLO, 1
    BRNE      _LOOPPUSH
    SBIW      _ACCCLO, 1
    BRNE      _LOOPFILL
  endasm;
{$ENDIF}
  LCD_CS:= true;
end;

procedure FillScreen(color : {$IFDEF LCD16BIT} word{$ELSE} longword{$ENDIF});
begin
  FillRect(0, 0, _width, _height, color);
end;

// gDrawType = (dtPixel, dtLineX, dtLineY, dtFillRect, dtClear);
userdevice GraphIOS(xs, ys, xe, ye : word; pattern, colorFg, colorBg : byte; draw : gDrawType) : byte;
begin
  // foreground color
  if colorFg > byte(max(tColors)) then
    ColorWfg:= $0000;   // clblack
    colorFg:= 1;
    ColorPfG:= colorFg;
  elsif colorFg <> ColorPfG then
    ColorPfG:= colorFg;
    ColorWfg:= ColorArr[(tColors(colorFg))];
  endif;

  // background color
  if colorBg > byte(max(tColors)) then
    ColorWbg:= $0000;   // clblack
    colorBg:= 1;
    ColorPbg:= colorBg;
  elsif colorBg <> ColorPbg then
    ColorPbg:= colorBg;
    ColorWbg:= ColorArr[(tColors(colorBg))];
  endif;

  case draw of
    dtClear    :
                 FillScreen(ColorWfg);
               |
    dtFillRect :
                 FillRect(xs, ys, xe, ye, ColorWfg);
               |

    dtLineX    :
                 LCD_CS:= false;
                 SetWindow(xs, ys, xe, ys);
                 pxCount:= (xe - xs);
                 asm: LDS       _ACCBHI, %.pxCount +1
                 asm: LDS       _ACCBLO, %.pxCount
                 if pattern = $FF then
                   asm: _LoopFillX:
                   WriteColor(ColorWfg);
                   asm: SBIW      _ACCBLO, 1
                   asm: BRNE      _LoopFillX
                 else
                   // pattern !!!
                   asm: LDD    _ACCELO, Y+3
                   asm: _LoopFillXP:
                   asm: ROL    _ACCELO
                   asm: BRCS   _LoopFillXPf
                   WriteColor(ColorWbg);
                   asm: CBR    _ACCELO, 1
                   asm: RJMP   _LoopFillXPe
                   asm: _LoopFillXPf:
                   WriteColor(ColorWfg);
                   asm: SBR    _ACCELO, 1
                   asm: _LoopFillXPe:
                   asm: SBIW      _ACCBLO, 1
                   asm: BRNE      _LoopFillXP
                 endif;
                 LCD_CS:= true;
               |
    dtLineY    :
                 LCD_CS:= false;
                 SetWindow(xs, ys, xs, ye);
                 pxCount:= (ye - ys);
                 asm: LDS       _ACCBHI, %.pxCount +1
                 asm: LDS       _ACCBLO, %.pxCount
                 if pattern = $FF then
                   asm: _LoopFillY:
                   WriteColor(ColorWfg);
                   asm: SBIW      _ACCBLO, 1
                   asm: BRNE      _LoopFillY
                 else
                   // pattern !!!
                   asm: LDD    _ACCELO, Y+3
                   asm: _LoopFillYP:
                   asm: ROL    _ACCELO
                   asm: BRCS   _LoopFillYPf
                   WriteColor(ColorWbg);
                   asm: CBR    _ACCELO, 1
                   asm: RJMP   _LoopFillYPe
                   asm: _LoopFillYPf:
                   WriteColor(ColorWfg);
                   asm: SBR    _ACCELO, 1
                   asm: _LoopFillYPe:
                   asm: SBIW      _ACCBLO, 1
                   asm: BRNE      _LoopFillYP
                 endif;
                 LCD_CS:= true;
               |

    dtPixel    :
                 LCD_CS:= false;
                 SetWindow(xs, ys, xs, ys);
                 WriteColor(ColorWfg);
                 LCD_CS:= true;
               |
  endcase;
  return(0);
end;

procedure InitAll;
begin
{$IFDEF LCD16BIT}
  LCD_DDRDATAH:= $FF; // hi data out
  LCD_DATAH:= 0;
{$ENDIF}
  LCD_DDRDATA:= $FF;  // lo data out
  LCD_DDRCTRL:= LCD_DDRCTRL or (LCD_WRmask or LCD_RDmask or LCD_RSTmask or LCD_RSmask or LCD_CSmask);  // set to output
  LCD_DDRCTRL:= LCD_DDRCTRL and (not LCD_IRQmask);  // Touch IRQ set as input pin
  Init_Lcd;
end;





Procedure Test_Frame;
Begin
  GSwitchView(0);
  gClearView(byte(myBkGround));

  GSetLineMode(wmSetPix);
  GSetTextMode(wmSetPix);
  gSetTextBkGnd(bkNormal);
  gSetTextColor(byte(myTextColor));

  GSwitchView(0);

// View 1 erstellen   X Anzeige
  GOpenView(1,   50, 10, 150, 50);
  GScaleView(1, -128, 128, 128, -128);
  gFrameView(1, $FF, byte(clRed));
  gSetBkColor(byte(myBtnColor));
  GSwitchView(1);
  gClearView(byte(myBkGround));
  gSetTextColor(byte(clYellow));
  gDrawString(-127, -80, 3, 3, TxtRot0, '1111');

  GSwitchView(0);

// View 2 erstellen   Y Anzeige
  GOpenView(2,   160, 10, 260, 50);
  GScaleView(2, -128, 128, 128, -128);
  gFrameView(2, $FF, byte(clRed));
  gSetBkColor(byte(myBtnColor));
  GSwitchView(2);
  gClearView(byte(myBkGround));
GSwitchView(2);
  gSetTextColor(byte(clYellow));
  gDrawString(-127, -80, 3, 3, TxtRot0, '2222');

  GSwitchView(0);

// View 3 erstellen   Z Anzeige
  GOpenView(3,   270, 10, 370, 50);
  GScaleView(3, -128, 128, 128, -128);
  gFrameView(3, $FF, byte(clRed));
  gSetBkColor(byte(myBtnColor));
  GSwitchView(3);
  gClearView(byte(myBkGround));
GSwitchView(3);
  gSetTextColor(byte(clYellow));
  gDrawString(-127, -80, 3, 3, TxtRot0, '3333');

  GSwitchView(0);

// View 4 erstellen   A Anzeige
  GOpenView(4,   380, 10, 480, 50);
  GScaleView(4, -128, 128, 128, -128);
  gFrameView(4, $FF, byte(clRed));
  gSetBkColor(byte(myBtnColor));
  GSwitchView(4);
  gClearView(byte(myBkGround));
  GSwitchView(4);
  gSetTextColor(byte(clYellow));
  GSwitchView(4);
  gDrawString(-127, -80, 3, 3, TxtRot0, '4444');

  GSwitchView(0);


//  InitRotButton;
end;
{--------------------------------------------------------------}
{ Main Program }
{$IDATA}

begin
  pwm:= 255;
  EnableInts($87);

  bb:= 0;
  InitAll;
  SetRotation(SWITCH_NONE);
  mdelay(100);
  SetBackLight(pwm);

  gClrScr(byte(myBkGround));          //Clr Screen

  //
  Test_Frame;


  
  loop
    nop;

  endloop;
end TFT_LCD.
